summaryrefslogtreecommitdiffstats
path: root/libkdegames/highscore/kexthighscore.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/highscore/kexthighscore.h')
-rw-r--r--libkdegames/highscore/kexthighscore.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/libkdegames/highscore/kexthighscore.h b/libkdegames/highscore/kexthighscore.h
index 7f16eac6..5809a896 100644
--- a/libkdegames/highscore/kexthighscore.h
+++ b/libkdegames/highscore/kexthighscore.h
@@ -51,17 +51,17 @@ KDE_EXPORT void setGameType(uint gameType);
* Configure the highscores.
* @return true if the configuration has been modified and saved
*/
-KDE_EXPORT bool configure(TQWidget *tqparent);
+KDE_EXPORT bool configure(TQWidget *parent);
/**
* Show the highscores lists.
*/
-KDE_EXPORT void show(TQWidget *tqparent);
+KDE_EXPORT void show(TQWidget *parent);
/**
* Submit a score. See @ref Manager for usage example.
*
* @param widget a widget used as tqparent for error message box.
*/
KDE_EXPORT void submitScore(const Score &score, TQWidget *widget);
@@ -51,17 +51,17 @@ KDE_EXPORT void setGameType(uint gameType);
* Submit a score. See @ref Manager for usage example.
*
- * @param widget a widget used as tqparent for error message box.
+ * @param widget a widget used as parent for error message box.
*/
KDE_EXPORT void submitScore(const Score &score, TQWidget *widget);